==> AGXUnreal-1.17.0_UE-5.4_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Dissipation/HingeMechanicalDamping.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Dissipation/DefaultHingeDissipation.h>
#include <openplx/Physics/Interactions/Dissipation/MechanicalDamping.h>
/* Generated code for model HingeMechanicalDamping */
namespace openplx::Physics3D::Interactions::Dissipation {
    /**
     *     Defines mechanical damping for all constrained degrees of freedom for a Hinge.
     *     */
    class HingeMechanicalDamping : public openplx::Physics3D::Interactions::Dissipation::DefaultHingeDissipation {
        protected:
            double m_default_damping;

        public:
            HingeMechanicalDamping();
            double default_damping() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Dissipation/HingeMechanicalDamping.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Dissipation/DefaultHingeDissipation.h>
#include <openplx/Physics/Interactions/Dissipation/MechanicalDamping.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model HingeMechanicalDamping */
namespace openplx::Physics3D::Interactions::Dissipation {
    /**
     *     Defines mechanical damping for all constrained degrees of freedom for a Hinge.
     *     */
    class OPENPLX_Physics3D_BUNDLE_EXPORT HingeMechanicalDamping : public openplx::Physics3D::Interactions::Dissipation::DefaultHingeDissipation {
        protected:
            double m_default_damping;

        public:
            HingeMechanicalDamping();
            virtual ~HingeMechanicalDamping();
            double default_damping() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
